@@ -122,8 +122,14 @@ Minion::Command::minion::job - Minion job command
     -a, --args <JSON array>   Arguments for new job in JSON format
     -d, --delay <seconds>     Delay new job for this many seconds
     -e, --enqueue <name>      New job to be enqueued
+    -h, --help                Show this summary of available options
+        --home <path>         Path to home directory of your application,
+                              defaults to the value of MOJO_HOME or auto
+                              detection
     -l, --limit <number>      Number of jobs/workers to show when listing them,
                               defaults to 100
+    -m, --mode <name>         Operating mode for your application, defaults to
+                              the value of MOJO_MODE/PLACK_ENV or "development"
     -o, --offset <number>     Number of jobs/workers to skip when listing them,
                               defaults to 0
     -p, --priority <number>   Priority of new job, defaults to 0
